#
# spec file for package python-wheel
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-wheel
Version:        0.29.0
Release:        24.4
Summary:        A built-package format for Python
License:        MIT
Group:          Development/Languages/Python
Url:            http://bitbucket.org/pypa/wheel/
Source:         https://pypi.python.org/packages/source/w/wheel/wheel-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# Test requirements:
BuildRequires:  python-cov-core >= 1.6
BuildRequires:  python-coverage
BuildRequires:  python-jsonschema
BuildRequires:  python-keyring
BuildRequires:  python-keyrings.alt
BuildRequires:  python-pytest
BuildRequires:  python-pytest-cov
BuildRequires:  python-pyxdg
Recommends:     python-ed25519ll
Recommends:     python-dirspec
Recommends:     python-keyring
Recommends:     python-keyrings.alt
Recommends:     python-pyxdg
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-argparse
Requires:       python-argparse
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
A built-package format for Python.

A wheel is a ZIP-format archive with a specially formatted filename
and the .whl extension. It is designed to contain all the files for a
PEP 376 compatible install in a way that is very close to the on-disk
format. Many packages will be properly installed with only the "Unpack"
step (simply extracting the file onto sys.path), and the unpacked archive
preserves enough information to "Spread" (copy data and scripts to their
final locations) at any later time.

The wheel project provides a bdist_wheel command for setuptools
(requires distribute >= 0.6.34). Wheel files can be
installed with a newer pip from https://github.com/pypa/pip
or with wheel's own command line utility.

The wheel documentation is at http://wheel.rtfd.org/. The
file format is documented in PEP 427
(http://www.python.org/dev/peps/pep-0427/).

The reference implementation is at http://bitbucket.org/dholth/wheel/

%prep
%setup -q -n wheel-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for b in wheel ; do
  mv %{buildroot}%{_bindir}/$b %{buildroot}%{_bindir}/$b-%{py_ver}
  touch %{buildroot}%{_sysconfdir}/alternatives/$b
  ln -sf %{_sysconfdir}/alternatives/$b %{buildroot}/%{_bindir}/$b
done

%check
PYTHONPATH=%{buildroot}%{python_sitelib} py.test
rm -rf %{buildroot}%{python_sitelib}/wheel/test/headers.dist

%post
update-alternatives --install %{_bindir}/wheel wheel %{_bindir}/wheel-%{py_ver} 20

%postun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove wheel %{_bindir}/wheel-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc CHANGES.txt README.txt LICENSE.txt
%{_bindir}/wheel
%{_bindir}/wheel-%{py_ver}
%ghost %{_sysconfdir}/alternatives/wheel
%{python_sitelib}/wheel-%{version}-py%{py_ver}.egg-info
%{python_sitelib}/wheel/

%changelog
* Mon May  9 2016 hpj@urpla.net
- update to 0.29.0:
  * Fix compression type of files in archive (Issue #155, Pull Request #62,
  thanks Xavier Fernandez)
- update to 0.28.0:
  * Fix file modes in archive (Issue #154)
- update to 0.27.0:
  * Support forcing a platform tag using `--plat-name` on pure-Python wheels, as
    well as nonstandard platform tags on non-pure wheels (Pull Request #60, Issue
    [#144], thanks Andrés Díaz)
  * Add SOABI tags to platform-specific wheels built for Python 2.X (Pull Request
    [#55], Issue #63, Issue #101)
  * Support reproducible wheel files, wheels that can be rebuilt and will hash to
    the same values as previous builds (Pull Request #52, Issue #143, thanks
    Barry Warsaw)
  * Support for changes in keyring >= 8.0 (Pull Request #61, thanks Jason R.
    Coombs)
  * Use the file context manager when checking if dependency_links.txt is empty,
    fixes problems building wheels under PyPy on Windows  (Issue #150, thanks
    Cosimo Lupo)
  * Don't attempt to (recursively) create a build directory ending with `..`
    (invalid on all platforms, but code was only executed on Windows) (Issue #91)
  * Added the PyPA Code of Conduct (Pull Request #56)
- fix dependencies
* Wed Oct 21 2015 hpj@urpla.net
- actually, _really_ test this module:
  call py.test directly with appropriate PYTHONPATH
* Tue Sep 29 2015 tbechtold@suse.com
- update to 0.26.0:
  * Fix multiple entrypoint comparison failure on Python 3 (Issue #148)
  * Add Python 3.5 to tox configuration
  * Deterministic (sorted) metadata
  * Fix tagging for Python 3.5 compatibility
  * Support py2-none-'arch' and py3-none-'arch' tags
  * Treat data-only wheels as pure
  * Write to temporary file and rename when using wheel install --force
* Wed Apr  1 2015 benoit.monin@gmx.fr
- update to version 0.24.0:
  * The python tag used for pure-python packages is now .pyN (major
    version only). This change actually occurred in 0.23.0 when the
  - -python-tag option was added, but was not explicitly mentioned
    in the changelog then.
  * wininst2wheel and egg2wheel removed. Use "wheel convert
    [archive]" instead.
  * Wheel now supports setuptools style conditional requirements via
    the extras_require={} syntax. Separate 'extra' names from
    conditions using the : character. Wheel's own setup.py does
    this. (The empty-string extra is the same as install_requires.)
    These conditional requirements should work the same whether the
    package is installed by wheel or by setup.py.
- additional changes from 0.23.0:
  * Compatibiltiy tag flags added to the bdist_wheel command
  * sdist should include files necessary for tests
  * 'wheel convert' can now also convert unpacked eggs to wheel
  * Rename pydist.json to metadata.json to avoid stepping on the PEP
  * The --skip-scripts option has been removed, and not generating
    scripts is now the default. The option was a temporary approach
    until installers could generate scripts themselves. That is now
    the case with pip 1.5 and later. Note that using pip 1.4 to
    install a wheel without scripts will leave the installation
    without entry-point wrappers. The "wheel install-scripts"
    command can be used to generate the scripts in such cases.
  * Thank you contributors
- removed wininst2wheel and egg2wheel:
  they are not in 0.24.0 anymore
* Mon Feb 10 2014 speilicke@suse.com
- Fix update-alternatives usage
* Tue Sep 17 2013 dmueller@suse.com
- update to 0.22.0:
- Include entry_points.txt, scripts a.k.a. commands, in experimental
  pydist.json
- Improved test_requires parsing
- Python 2.6 fixes, "wheel version" command courtesy pombredanne
* Tue Sep 10 2013 toddrme2178@gmail.com
- Add BuildRequires:  python-argparse for SLE
* Tue Aug 13 2013 speilicke@suse.com
- Use upstream tarball
* Mon Aug 12 2013 speilicke@suse.com
- Initial version
